connect to TLMA user tlmsrv%

create procedure ADM.DROP_VIEW_IF_EXISTS(in VIEW_NAME char(100))
	begin
	declare STMT char(100);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP VIEW ' concat VIEW_NAME;
	prepare S1 from STMT;
	execute S1;
	end%

call ADM.DROP_VIEW_IF_EXISTS('ADM.FIX_VIEW')%

-- Create a temporray view to fix the nodes creation time
CREATE VIEW ADM.FIX_VIEW (NODE_ID, CORRECT_DATE, OLD_DATE) AS
    with tmp1 (A_ID, N_ID, A_TIME, N_TIME) as
        (select a.id, n.id, min(rel.START_TIME), n.CREATION_TIME from adm.AGENT_FULL_V a
            join adm.AGT_VM_REL rel on rel.AGENT_ID = a.id
            join adm.vm v on v.id = rel.VM_ID
            join adm.NODE n on n.id = v.NODE_ID
            group by a.id, n.id, n.CREATION_TIME),
         tmp2 (N_ID, CORRECT_TIME, OLD_TIME) as
         (select t.N_ID, min(t.A_TIME), t.N_TIME 
            from tmp1 as t 
            where date(N_TIME) > date(A_TIME) 
            group by t.N_ID, t.N_TIME
         )
    select * from tmp2%

-- Update the nodes creation time according to FIX_VIEW view
update adm.node n set CREATION_TIME = (select CORRECT_DATE from adm.fix_view where NODE_ID = n.id)
where n.id in (select distinct NODE_ID from adm.fix_view)%

-- FIX for bug with incorrect LOCALE
delete from adm.MEASURE where QUANTITY < 0%
delete from adm.MEASURE_RAW where QUANTITY < 0%
update adm.MEASURE set QUANTITY = (QUANTITY / 1000000) where QUANTITY >= 100000000%
update adm.MEASURE_RAW set QUANTITY = (QUANTITY / 1000000) where QUANTITY >= 100000000%

-- Setting the FIRST_TO_AGGREGATE_DAY to the end_date of the last signed report or the db creation time
update adm.control 
  set value =
    case when (select count(*) from adm.IBM_REPORT where FINALIZATION_TIME is not null)=0 then 
      (select SUBSTR(CHAR(date(con.value),ISO),1,10) from adm.CONTROL con where con.name = 'DB_CREATION')
    else
      (
        select
        SUBSTR(CHAR(max(end_date) + 1 day, ISO), 1, 10)
        from adm.ibm_report
        where finalization_time is not null
      ) 
    end
 where name='FIRST_TO_AGGREGATE_DAY'%

-- drop the view
call ADM.DROP_VIEW_IF_EXISTS('ADM.FIX_VIEW')%

drop procedure ADM.DROP_VIEW_IF_EXISTS%

disconnect TLMA%