#!/bin/ksh
###############################################################################
# Licensed Materials - Property of IBM
# 5724-T40 IBM License Metric Tool
# 5724-S94 IBM Tivoli Asset Discovery for Distributed
#
# (C) Copyright IBM Corp. 2004, 2011.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################

dir_path=$1
backup_dir=back

print_usage()
{
	echo "Incorrect number of arguments"
	echo "usage: install.sh <ILMT|TAD4D-install-dir>"
}

#Checking the parameter
if [ -n "$dir_path" ]
then
	echo "Using ILMT/TAD4D install location: "$dir_path
else 
	print_usage
	exit 1
fi

#Checking whether admin/master.tag file exists in product installation directory
master_tag_file=$dir_path"/admin/master.tag"
if [ -f "$master_tag_file" ]
then
	echo "SUCCESS: master.tag file found in product installation directory"
else
	echo "Error: There is no admin/master.tag file in product installation directory ("$dir_path")"
	echo "Please check whether the given path is correct."
	exit 1
fi

#Checking the software name in product.xml file
prod_name=`cat $master_tag_file | grep 'LMT/TAD4D Tags'`
if [[ "$prod_name" == "" ]]
then
	echo "Error: Incorrect product name in admin/master.tag file was found."
	exit 1
fi

#Checking the software version in admin/master.tag file
version=`cat $master_tag_file | grep 'PRODUCT_VERSION_NUMBER=7.2.2.0'`
if [[ "$version" == "" ]]
then
	echo "Error: Unsupported product version, it needs to be ILMT/TAD4D 7.2.2.0"
	exit 1
fi

#Checking whether it is ILMT or TAD4D installation
lmt_war_path=$dir_path"/eWAS/systemApps/isclite.ear/lmt_admin.war"
tad4d_war_path=$dir_path"/eWAS/systemApps/isclite.ear/tad4d_admin.war"
admin__libdir=$dir_path"/eWAS/systemApps/isclite.ear/lmt_admin.war/WEB-INF/lib/"
msghandler_libdir=$dir_path"/eWAS/profiles/AppSrv01/installedApps/cell1/LMT-TAD4D_Agent_message_handler.ear/com.ibm.license.mgmt.msghandler.web.war/WEB-INF/lib/"

if [ -d "$lmt_war_path" ]
then
	echo "ILMT 7.2.2.0 installation was found."
else
	if [ -d "$tad4d_war_path" ]
	then
		echo "TAD4D 7.2.2.0 installation was found."
		admin__libdir=$dir_path"/eWAS/systemApps/isclite.ear/tad4d_admin.war/WEB-INF/lib/"
	else
		echo "Error: Cannot locate the product war directory"
		exit 1
	fi
fi

#Checking whether lib directories exists
if [[ ! ( -d "$admin__libdir" && -d "$msghandler_libdir" ) ]]
then
	echo "Error: the msghandler or admin server lib directory cannot be located."
	exit 1
fi

#if the Interim fix was already installed
fix_file=$dir_path"/722_if1.dat"
if [ -f "$fix_file" ]
then
	echo "Error: Interim Fix 7.2.2.0 IF1 is already installed."
	exit 1
fi

#Stopping the server
srvstop=$dir_path"/cli/srvstop.sh"
if [ -f "$srvstop" ]
then
	echo "Stopping the server ..."
	$srvstop
	return_code=$?
	if [[ $return_code -eq 0 || $return_code -eq 246 ]]
	then
		echo "Server stopped successfully."
	else
		echo "Error: Some problems occur during stopping the server."
		echo "Try to stop the application server manually and try again."
		exit 1
	fi
else
	echo "Error: Cannot find srvstop.sh script to stop the server."
	exit 1
fi

#backup
echo "Creating backup files"
rm -rf $backup_dir
mkdir $backup_dir
if [ $? -ne 0 ]
then
	echo "Error: Cannot create the backup directory."
	exit 1
fi

cp $admin__libdir"com.ibm.license.mgmt.core.jar" ./$backup_dir/

echo "Replacing the jar files"

cp -f com.ibm.license.mgmt.core.jar $admin__libdir
cp -f com.ibm.license.mgmt.core.jar $msghandler_libdir

echo "All files replaced"

echo "Creating a 7.2.2.0 Interim Fix file."
echo "7.2.2.0 IF1" > $fix_file

echo "Replacing files for ILMT/TAD4D 7.2.2.0 IF1 Interim Fix ended successfully."
echo "ILMT/TAD4D server is now stopped since additional, manual action is still needed."
echo "Please go to the machine where TLMA DB is placed and run the SQL script ILMT_TAD4D_7220_IF1_script.sql"
echo "which comes with the Interim Fix. To do this execute the following DB2 command:"
echo "                     db2 -vf ILMT_TAD4D_7220_IF1_script.sql -td%"
echo "Once this task is completed, please start the ILMT/TAD4D server to finish Interim Fix application."

exit 0
